print_file_content: A function which reads the text from a file and prints it

Description Usage Arguments Examples

View source: R/print_file_content.R

Description

A function which reads the text from a file and prints it

Usage

1
print_file_content(file_path)

Arguments

file_path

character - path to the file

Examples

1
2
3
path <- system.file("exdata", "file.txt",
                    package = "pkgTemplateR")
print_file_content(file_path = path)

CTU-Basel/pkgTemplateR documentation built on Aug. 4, 2020, 2:17 a.m.